@@ -14,7 +14,7 @@ from .mongo_tools import clean_json
 from .data_utils import to_dicts
 from .parsing import parse_float, parse_int, lower_string
 
-__version__ = "0.1.22"
+__version__ = "0.1.23"
 
 
 def logged_user(logger=logger):
@@ -173,3 +173,7 @@ def pairwise(iterable: Iterable):
 
 def get_stdout_lines(command: List[str]) -> List[str]:
     return check_output(command).decode().splitlines()
+
+
+def lookup(iterable: Iterable, key: callable):
+    return {key(i): i for i in iterable}
