@@ -1,5 +1,6 @@
 import pytest
 from sparkles import parse_float, parse_int
+from sparkles.parsing import lower_string
 
 valid_float_inputs = [
     ("3,000.00", 3000.0),
@@ -24,7 +25,7 @@ invalid_float_inputs = [
 
 
 @pytest.mark.parametrize("float_str_value", invalid_float_inputs)
-def test_parsing_valid_floats(float_str_value):
+def test_parsing_invalid_floats_raises(float_str_value):
     with pytest.raises(ValueError):
         parse_float(float_str_value)
 
@@ -55,6 +56,24 @@ invalid_int_inputs = [
 
 
 @pytest.mark.parametrize("int_str_value", invalid_int_inputs)
-def test_parsing_valid_floats(int_str_value):
+def test_parsing_invalid_floats_raises_value_error(int_str_value):
     with pytest.raises(ValueError):
         parse_int(int_str_value)
+
+
+def test_string_lower_sends_values_error_on_none():
+    with pytest.raises(ValueError):
+        lower_string(None)
+
+
+valid_string_lower_inputs = [
+    ("TEST", "test"),
+    (" TEST", "test"),
+    ("TEST ", "test"),
+    ("test", "test"),
+]
+
+
+@pytest.mark.parametrize("string_to_lower, expected", valid_string_lower_inputs)
+def test_string_lower_valid_values(string_to_lower, expected):
+    pass
